@@ -1,13 +1,12 @@
 package Moose::Meta::Class;
-our $VERSION = '2.1605';
+our $VERSION = '2.1807';
 
 use strict;
 use warnings;
 
 use Class::MOP;
 use Data::OptList;
-use List::Util 1.33 qw( any first );
-use List::MoreUtils qw( uniq first_index );
+use List::Util 1.33 qw( any );
 use Scalar::Util 'blessed';
 
 use Moose::Meta::Method::Overridden;
@@ -376,16 +375,21 @@ sub _inline_check_required_attr {
     return unless $attr->can('is_required') && $attr->is_required;
     return if $attr->has_default || $attr->has_builder;
 
-    return (
-        'if (!exists $params->{\'' . $attr->init_arg . '\'}) {',
-            $self->_inline_throw_exception(
-                AttributeIsRequired =>
-                'params         => $params, '.
-                'class_name     => $class_name, '.
-                'attribute_name => "'.quotemeta($attr->name).'"'
-            ).';',
-        '}',
-    );
+    my $throw = $self->_inline_throw_exception(
+        'AttributeIsRequired',
+        sprintf(
+            <<'EOF', quotemeta( $attr->name ), quotemeta( $attr->init_arg ) ), );
+params             => $params,
+class_name         => $class_name,
+attribute_name     => "%s",
+attribute_init_arg => "%s",
+EOF
+
+    return sprintf( <<'EOF', quotemeta( $attr->init_arg ), $throw )
+if ( !exists $params->{"%s"} ) {
+    %s;
+}
+EOF
 }
 
 # XXX: these two are duplicated from cmop, because we have to pass the tc stuff
@@ -802,7 +806,7 @@ Moose::Meta::Class - The Moose metaclass
 
 =head1 VERSION
 
-version 2.1605
+version 2.1807
 
 =head1 DESCRIPTION
 
