@@ -1,10 +1,9 @@
 package Moose::Meta::Method::Accessor::Native::Array::natatime;
-our $VERSION = '2.1604';
+our $VERSION = '2.1807';
 
 use strict;
 use warnings;
 
-use List::MoreUtils ();
 use Params::Util ();
 
 use Moose::Role;
@@ -45,7 +44,9 @@ sub _inline_return_value {
     my ($slot_access) = @_;
 
     return (
-        'my $iter = List::MoreUtils::natatime($_[0], @{ (' . $slot_access . ') });',
+        'my $step = $_[0];',
+        'my @values = @{ (' . $slot_access . ') };',
+        'my $iter = sub { splice @values, 0, $step };',
         'if ($_[1]) {',
             'while (my @vals = $iter->()) {',
                 '$_[1]->(@vals);',
