@@ -1,10 +1,10 @@
 package Moose::Meta::Method::Accessor::Native::Hash::set;
-our $VERSION = '2.1605';
+our $VERSION = '2.1807';
 
 use strict;
 use warnings;
 
-use List::MoreUtils ();
+use List::Util 1.32;
 use Moose::Role;
 
 with 'Moose::Meta::Method::Accessor::Native::Hash::Writer';
@@ -65,11 +65,7 @@ sub _inline_coerce_new_values {
 
     # Is there a simpler way to do this?
     return (
-        'my $iter = List::MoreUtils::natatime(2, @_);',
-        '@_ = ();',
-        'while (my ($key, $val) = $iter->()) {',
-            'push @_, $key, $member_coercion->($val);',
-        '}',
+        '@_ = List::Util::pairmap { $a => $member_coercion->($b) } @_;',
     );
 };
 
