@@ -1,12 +1,10 @@
 package Moose::Meta::Method::Constructor;
-$Moose::Meta::Method::Constructor::VERSION = '2.1213';
+our $VERSION = '2.1807';
+
 use strict;
 use warnings;
 
-use Carp ();
-use List::MoreUtils 'any';
-use Scalar::Util 'blessed', 'weaken', 'looks_like_number', 'refaddr';
-use Try::Tiny;
+use Scalar::Util 'weaken';
 
 use parent 'Moose::Meta::Method',
          'Class::MOP::Method::Constructor';
@@ -72,7 +70,7 @@ Moose::Meta::Method::Constructor - Method Meta Object for constructors
 
 =head1 VERSION
 
-version 2.1213
+version 2.1807
 
 =head1 DESCRIPTION
 
@@ -139,7 +137,7 @@ Matt S Trout <mst@shadowcat.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2006 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
