@@ -1,8 +1,6 @@
 package Moose::Meta::TypeConstraint;
-BEGIN {
-  $Moose::Meta::TypeConstraint::AUTHORITY = 'cpan:STEVAN';
-}
-$Moose::Meta::TypeConstraint::VERSION = '2.1210';
+our $VERSION = '2.1807';
+
 use strict;
 use warnings;
 use metaclass;
@@ -12,9 +10,8 @@ use overload '0+'     => sub { refaddr(shift) }, # id an object
              bool     => sub { 1 },
              fallback => 1;
 
-use Class::Load qw(load_class);
 use Eval::Closure;
-use Scalar::Util qw(blessed refaddr);
+use Scalar::Util qw(refaddr);
 use Sub::Name qw(subname);
 use Try::Tiny;
 
@@ -209,15 +206,15 @@ sub inline_environment {
 }
 
 sub assert_valid {
-    my ($self, $value) = @_;
+    my ( $self, $value ) = @_;
 
-    my $error = $self->validate($value);
-    return 1 if ! defined $error;
+    return 1 if $self->check($value);
 
-    throw_exception( ValidationFailedForTypeConstraint => type          => $self,
-                                                          error_message => $error,
-                                                          value         => $value
-                   );
+    throw_exception(
+        'ValidationFailedForTypeConstraint',
+        type  => $self,
+        value => $value
+    );
 }
 
 sub get_message {
@@ -234,7 +231,8 @@ sub get_message {
 sub equals {
     my ( $self, $type_or_name ) = @_;
 
-    my $other = Moose::Util::TypeConstraints::find_type_constraint($type_or_name) or return;
+    my $other = Moose::Util::TypeConstraints::find_type_constraint($type_or_name);
+    return if not $other;
 
     return 1 if $self == $other;
 
@@ -253,7 +251,8 @@ sub equals {
 sub is_a_type_of {
     my ($self, $type_or_name) = @_;
 
-    my $type = Moose::Util::TypeConstraints::find_type_constraint($type_or_name) or return;
+    my $type = Moose::Util::TypeConstraints::find_type_constraint($type_or_name);
+    return if not $type;
 
     ($self->equals($type) || $self->is_subtype_of($type));
 }
@@ -261,7 +260,8 @@ sub is_a_type_of {
 sub is_subtype_of {
     my ($self, $type_or_name) = @_;
 
-    my $type = Moose::Util::TypeConstraints::find_type_constraint($type_or_name) or return;
+    my $type = Moose::Util::TypeConstraints::find_type_constraint($type_or_name);
+    return if not $type;
 
     my $current = $self;
 
@@ -378,7 +378,7 @@ Moose::Meta::TypeConstraint - The Moose Type Constraint metaclass
 
 =head1 VERSION
 
-version 2.1210
+version 2.1807
 
 =head1 DESCRIPTION
 
@@ -393,13 +393,11 @@ C<Moose::Meta::TypeConstraint> is a subclass of L<Class::MOP::Object>.
 
 =head1 METHODS
 
-=over 4
-
-=item B<< Moose::Meta::TypeConstraint->new(%options) >>
+=head2 Moose::Meta::TypeConstraint->new(%options)
 
 This creates a new type constraint based on the provided C<%options>:
 
-=over 8
+=over 4
 
 =item * name
 
@@ -442,23 +440,23 @@ the values are I<references> to the variables.
 
 =back
 
-=item B<< $constraint->equals($type_name_or_object) >>
+=head2 $constraint->equals($type_name_or_object)
 
 Returns true if the supplied name or type object is the same as the
 current type.
 
-=item B<< $constraint->is_subtype_of($type_name_or_object) >>
+=head2 $constraint->is_subtype_of($type_name_or_object)
 
 Returns true if the supplied name or type object is a parent of the
 current type.
 
-=item B<< $constraint->is_a_type_of($type_name_or_object) >>
+=head2 $constraint->is_a_type_of($type_name_or_object)
 
 Returns true if the given type is the same as the current type, or is
 a parent of the current type. This is a shortcut for checking
 C<equals> and C<is_subtype_of>.
 
-=item B<< $constraint->coerce($value) >>
+=head2 $constraint->coerce($value)
 
 This will attempt to coerce the value to the type. If the type does not
 have any defined coercions this will throw an error.
@@ -466,78 +464,78 @@ have any defined coercions this will throw an error.
 If no coercion can produce a value matching C<$constraint>, the original
 value is returned.
 
-=item B<< $constraint->assert_coerce($value) >>
+=head2 $constraint->assert_coerce($value)
 
 This method behaves just like C<coerce>, but if the result is not valid
 according to C<$constraint>, an error is thrown.
 
-=item B<< $constraint->check($value) >>
+=head2 $constraint->check($value)
 
 Returns true if the given value passes the constraint for the type.
 
-=item B<< $constraint->validate($value) >>
+=head2 $constraint->validate($value)
 
 This is similar to C<check>. However, if the type I<is valid> then the
 method returns an explicit C<undef>. If the type is not valid, we call
 C<< $self->get_message($value) >> internally to generate an error
 message.
 
-=item B<< $constraint->assert_valid($value) >>
+=head2 $constraint->assert_valid($value)
 
 Like C<check> and C<validate>, this method checks whether C<$value> is
 valid under the constraint.  If it is, it will return true.  If it is not,
 an exception will be thrown with the results of
 C<< $self->get_message($value) >>.
 
-=item B<< $constraint->name >>
+=head2 $constraint->name
 
 Returns the type's name, as provided to the constructor.
 
-=item B<< $constraint->parent >>
+=head2 $constraint->parent
 
 Returns the type's parent, as provided to the constructor, if any.
 
-=item B<< $constraint->has_parent >>
+=head2 $constraint->has_parent
 
 Returns true if the type has a parent type.
 
-=item B<< $constraint->parents >>
+=head2 $constraint->parents
 
 Returns all of the types parents as an list of type constraint objects.
 
-=item B<< $constraint->constraint >>
+=head2 $constraint->constraint
 
 Returns the type's constraint, as provided to the constructor.
 
-=item B<< $constraint->get_message($value) >>
+=head2 $constraint->get_message($value)
 
 This generates a method for the given value. If the type does not have
 an explicit message, we generate a default message.
 
-=item B<< $constraint->has_message >>
+=head2 $constraint->has_message
 
 Returns true if the type has a message.
 
-=item B<< $constraint->message >>
+=head2 $constraint->message
 
 Returns the type's message as a subroutine reference.
 
-=item B<< $constraint->coercion >>
+=head2 $constraint->coercion
 
 Returns the type's L<Moose::Meta::TypeCoercion> object, if one
 exists.
 
-=item B<< $constraint->has_coercion >>
+=head2 $constraint->has_coercion
 
 Returns true if the type has a coercion.
 
-=item B<< $constraint->can_be_inlined >>
+=head2 $constraint->can_be_inlined
 
 Returns true if this type constraint can be inlined. A type constraint which
 subtypes an inlinable constraint and does not add an additional constraint
 "inherits" its parent type's inlining.
 
-=item B<< $constraint->create_child_type(%options) >>
+=head2 $constraint->create_child_type(%options)
 
 This returns a new type constraint of the same class using the
 provided C<%options>. The C<parent> option will be the current type.
@@ -545,8 +543,6 @@ provided C<%options>. The C<parent> option will be the current type.
 This method exists so that subclasses of this class can override this
 behavior and change how child types are created.
 
-=back
-
 =head1 BUGS
 
 See L<Moose/BUGS> for details on reporting bugs.
@@ -599,7 +595,7 @@ Matt S Trout <mst@shadowcat.co.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2006 by Infinity Interactive, Inc..
+This software is copyright (c) 2006 by Infinity Interactive, Inc.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
